@@ -1,7 +1,7 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-10.
+# Conversion routines for ISO-8859-8.
 # Copyright (C) 2002-2017 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_10;
+package Locale::RecodeData::ISO_8859_8;
 
 use strict;
 
@@ -187,101 +187,101 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0x0104,
-    0x0112,
-    0x0122,
-    0x012a,
-    0x0128,
-    0x0136,
+    0xfffd,
+    0x00a2,
+    0x00a3,
+    0x00a4,
+    0x00a5,
+    0x00a6,
     0x00a7,
-    0x013b,
-    0x0110,
-    0x0160,
-    0x0166,
-    0x017d,
+    0x00a8,
+    0x00a9,
+    0x00d7,
+    0x00ab,
+    0x00ac,
     0x00ad,
-    0x016a,
-    0x014a,
+    0x00ae,
+    0x00af,
     0x00b0,
-    0x0105,
-    0x0113,
-    0x0123,
-    0x012b,
-    0x0129,
-    0x0137,
+    0x00b1,
+    0x00b2,
+    0x00b3,
+    0x00b4,
+    0x00b5,
+    0x00b6,
     0x00b7,
-    0x013c,
-    0x0111,
-    0x0161,
-    0x0167,
-    0x017e,
-    0x2015,
-    0x016b,
-    0x014b,
-    0x0100,
-    0x00c1,
-    0x00c2,
-    0x00c3,
-    0x00c4,
-    0x00c5,
-    0x00c6,
-    0x012e,
-    0x010c,
-    0x00c9,
-    0x0118,
-    0x00cb,
-    0x0116,
-    0x00cd,
-    0x00ce,
-    0x00cf,
-    0x00d0,
-    0x0145,
-    0x014c,
-    0x00d3,
-    0x00d4,
-    0x00d5,
-    0x00d6,
-    0x0168,
-    0x00d8,
-    0x0172,
-    0x00da,
-    0x00db,
-    0x00dc,
-    0x00dd,
-    0x00de,
-    0x00df,
-    0x0101,
-    0x00e1,
-    0x00e2,
-    0x00e3,
-    0x00e4,
-    0x00e5,
-    0x00e6,
-    0x012f,
-    0x010d,
-    0x00e9,
-    0x0119,
-    0x00eb,
-    0x0117,
-    0x00ed,
-    0x00ee,
-    0x00ef,
-    0x00f0,
-    0x0146,
-    0x014d,
-    0x00f3,
-    0x00f4,
-    0x00f5,
-    0x00f6,
-    0x0169,
-    0x00f8,
-    0x0173,
-    0x00fa,
-    0x00fb,
-    0x00fc,
-    0x00fd,
-    0x00fe,
-    0x0138,
+    0x00b8,
+    0x00b9,
+    0x00f7,
+    0x00bb,
+    0x00bc,
+    0x00bd,
+    0x00be,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0x2017,
+    0x05d0,
+    0x05d1,
+    0x05d2,
+    0x05d3,
+    0x05d4,
+    0x05d5,
+    0x05d6,
+    0x05d7,
+    0x05d8,
+    0x05d9,
+    0x05da,
+    0x05db,
+    0x05dc,
+    0x05dd,
+    0x05de,
+    0x05df,
+    0x05e0,
+    0x05e1,
+    0x05e2,
+    0x05e3,
+    0x05e4,
+    0x05e5,
+    0x05e6,
+    0x05e7,
+    0x05e8,
+    0x05e9,
+    0x05ea,
+    0xfffd,
+    0xfffd,
+    0x200e,
+    0x200f,
+    0xfffd,
 );
 
 my @to_utf8 = (
@@ -446,101 +446,101 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xc4\x84",
-    "\xc4\x92",
-    "\xc4\xa2",
-    "\xc4\xaa",
-    "\xc4\xa8",
-    "\xc4\xb6",
+    "\xef\xbf\xbd",
+    "\xc2\xa2",
+    "\xc2\xa3",
+    "\xc2\xa4",
+    "\xc2\xa5",
+    "\xc2\xa6",
     "\xc2\xa7",
-    "\xc4\xbb",
-    "\xc4\x90",
-    "\xc5\xa0",
-    "\xc5\xa6",
-    "\xc5\xbd",
+    "\xc2\xa8",
+    "\xc2\xa9",
+    "\xc3\x97",
+    "\xc2\xab",
+    "\xc2\xac",
     "\xc2\xad",
-    "\xc5\xaa",
-    "\xc5\x8a",
+    "\xc2\xae",
+    "\xc2\xaf",
     "\xc2\xb0",
-    "\xc4\x85",
-    "\xc4\x93",
-    "\xc4\xa3",
-    "\xc4\xab",
-    "\xc4\xa9",
-    "\xc4\xb7",
+    "\xc2\xb1",
+    "\xc2\xb2",
+    "\xc2\xb3",
+    "\xc2\xb4",
+    "\xc2\xb5",
+    "\xc2\xb6",
     "\xc2\xb7",
-    "\xc4\xbc",
-    "\xc4\x91",
-    "\xc5\xa1",
-    "\xc5\xa7",
-    "\xc5\xbe",
-    "\xe2\x80\x95",
-    "\xc5\xab",
-    "\xc5\x8b",
-    "\xc4\x80",
-    "\xc3\x81",
-    "\xc3\x82",
-    "\xc3\x83",
-    "\xc3\x84",
-    "\xc3\x85",
-    "\xc3\x86",
-    "\xc4\xae",
-    "\xc4\x8c",
-    "\xc3\x89",
-    "\xc4\x98",
-    "\xc3\x8b",
-    "\xc4\x96",
-    "\xc3\x8d",
-    "\xc3\x8e",
-    "\xc3\x8f",
-    "\xc3\x90",
-    "\xc5\x85",
-    "\xc5\x8c",
-    "\xc3\x93",
-    "\xc3\x94",
-    "\xc3\x95",
-    "\xc3\x96",
-    "\xc5\xa8",
-    "\xc3\x98",
-    "\xc5\xb2",
-    "\xc3\x9a",
-    "\xc3\x9b",
-    "\xc3\x9c",
-    "\xc3\x9d",
-    "\xc3\x9e",
-    "\xc3\x9f",
-    "\xc4\x81",
-    "\xc3\xa1",
-    "\xc3\xa2",
-    "\xc3\xa3",
-    "\xc3\xa4",
-    "\xc3\xa5",
-    "\xc3\xa6",
-    "\xc4\xaf",
-    "\xc4\x8d",
-    "\xc3\xa9",
-    "\xc4\x99",
-    "\xc3\xab",
-    "\xc4\x97",
-    "\xc3\xad",
-    "\xc3\xae",
-    "\xc3\xaf",
-    "\xc3\xb0",
-    "\xc5\x86",
-    "\xc5\x8d",
-    "\xc3\xb3",
-    "\xc3\xb4",
-    "\xc3\xb5",
-    "\xc3\xb6",
-    "\xc5\xa9",
-    "\xc3\xb8",
-    "\xc5\xb3",
-    "\xc3\xba",
-    "\xc3\xbb",
-    "\xc3\xbc",
-    "\xc3\xbd",
-    "\xc3\xbe",
-    "\xc4\xb8",
+    "\xc2\xb8",
+    "\xc2\xb9",
+    "\xc3\xb7",
+    "\xc2\xbb",
+    "\xc2\xbc",
+    "\xc2\xbd",
+    "\xc2\xbe",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xe2\x80\x97",
+    "\xd7\x90",
+    "\xd7\x91",
+    "\xd7\x92",
+    "\xd7\x93",
+    "\xd7\x94",
+    "\xd7\x95",
+    "\xd7\x96",
+    "\xd7\x97",
+    "\xd7\x98",
+    "\xd7\x99",
+    "\xd7\x9a",
+    "\xd7\x9b",
+    "\xd7\x9c",
+    "\xd7\x9d",
+    "\xd7\x9e",
+    "\xd7\x9f",
+    "\xd7\xa0",
+    "\xd7\xa1",
+    "\xd7\xa2",
+    "\xd7\xa3",
+    "\xd7\xa4",
+    "\xd7\xa5",
+    "\xd7\xa6",
+    "\xd7\xa7",
+    "\xd7\xa8",
+    "\xd7\xa9",
+    "\xd7\xaa",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xe2\x80\x8e",
+    "\xe2\x80\x8f",
+    "\xef\xbf\xbd",
 );
 
 my %from_ucs4 = (
@@ -705,101 +705,65 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
+    0x000000a2 => "\xa2",
+    0x000000a3 => "\xa3",
+    0x000000a4 => "\xa4",
+    0x000000a5 => "\xa5",
+    0x000000a6 => "\xa6",
     0x000000a7 => "\xa7",
+    0x000000a8 => "\xa8",
+    0x000000a9 => "\xa9",
+    0x000000ab => "\xab",
+    0x000000ac => "\xac",
     0x000000ad => "\xad",
+    0x000000ae => "\xae",
+    0x000000af => "\xaf",
     0x000000b0 => "\xb0",
+    0x000000b1 => "\xb1",
+    0x000000b2 => "\xb2",
+    0x000000b3 => "\xb3",
+    0x000000b4 => "\xb4",
+    0x000000b5 => "\xb5",
+    0x000000b6 => "\xb6",
     0x000000b7 => "\xb7",
-    0x000000c1 => "\xc1",
-    0x000000c2 => "\xc2",
-    0x000000c3 => "\xc3",
-    0x000000c4 => "\xc4",
-    0x000000c5 => "\xc5",
-    0x000000c6 => "\xc6",
-    0x000000c9 => "\xc9",
-    0x000000cb => "\xcb",
-    0x000000cd => "\xcd",
-    0x000000ce => "\xce",
-    0x000000cf => "\xcf",
-    0x000000d0 => "\xd0",
-    0x000000d3 => "\xd3",
-    0x000000d4 => "\xd4",
-    0x000000d5 => "\xd5",
-    0x000000d6 => "\xd6",
-    0x000000d8 => "\xd8",
-    0x000000da => "\xda",
-    0x000000db => "\xdb",
-    0x000000dc => "\xdc",
-    0x000000dd => "\xdd",
-    0x000000de => "\xde",
-    0x000000df => "\xdf",
-    0x000000e1 => "\xe1",
-    0x000000e2 => "\xe2",
-    0x000000e3 => "\xe3",
-    0x000000e4 => "\xe4",
-    0x000000e5 => "\xe5",
-    0x000000e6 => "\xe6",
-    0x000000e9 => "\xe9",
-    0x000000eb => "\xeb",
-    0x000000ed => "\xed",
-    0x000000ee => "\xee",
-    0x000000ef => "\xef",
-    0x000000f0 => "\xf0",
-    0x000000f3 => "\xf3",
-    0x000000f4 => "\xf4",
-    0x000000f5 => "\xf5",
-    0x000000f6 => "\xf6",
-    0x000000f8 => "\xf8",
-    0x000000fa => "\xfa",
-    0x000000fb => "\xfb",
-    0x000000fc => "\xfc",
-    0x000000fd => "\xfd",
-    0x000000fe => "\xfe",
-    0x00000100 => "\xc0",
-    0x00000101 => "\xe0",
-    0x00000104 => "\xa1",
-    0x00000105 => "\xb1",
-    0x0000010c => "\xc8",
-    0x0000010d => "\xe8",
-    0x00000110 => "\xa9",
-    0x00000111 => "\xb9",
-    0x00000112 => "\xa2",
-    0x00000113 => "\xb2",
-    0x00000116 => "\xcc",
-    0x00000117 => "\xec",
-    0x00000118 => "\xca",
-    0x00000119 => "\xea",
-    0x00000122 => "\xa3",
-    0x00000123 => "\xb3",
-    0x00000128 => "\xa5",
-    0x00000129 => "\xb5",
-    0x0000012a => "\xa4",
-    0x0000012b => "\xb4",
-    0x0000012e => "\xc7",
-    0x0000012f => "\xe7",
-    0x00000136 => "\xa6",
-    0x00000137 => "\xb6",
-    0x00000138 => "\xff",
-    0x0000013b => "\xa8",
-    0x0000013c => "\xb8",
-    0x00000145 => "\xd1",
-    0x00000146 => "\xf1",
-    0x0000014a => "\xaf",
-    0x0000014b => "\xbf",
-    0x0000014c => "\xd2",
-    0x0000014d => "\xf2",
-    0x00000160 => "\xaa",
-    0x00000161 => "\xba",
-    0x00000166 => "\xab",
-    0x00000167 => "\xbb",
-    0x00000168 => "\xd7",
-    0x00000169 => "\xf7",
-    0x0000016a => "\xae",
-    0x0000016b => "\xbe",
-    0x00000172 => "\xd9",
-    0x00000173 => "\xf9",
-    0x0000017d => "\xac",
-    0x0000017e => "\xbc",
-    0x00002015 => "\xbd",
+    0x000000b8 => "\xb8",
+    0x000000b9 => "\xb9",
+    0x000000bb => "\xbb",
+    0x000000bc => "\xbc",
+    0x000000bd => "\xbd",
+    0x000000be => "\xbe",
+    0x000000d7 => "\xaa",
+    0x000000f7 => "\xba",
+    0x000005d0 => "\xe0",
+    0x000005d1 => "\xe1",
+    0x000005d2 => "\xe2",
+    0x000005d3 => "\xe3",
+    0x000005d4 => "\xe4",
+    0x000005d5 => "\xe5",
+    0x000005d6 => "\xe6",
+    0x000005d7 => "\xe7",
+    0x000005d8 => "\xe8",
+    0x000005d9 => "\xe9",
+    0x000005da => "\xea",
+    0x000005db => "\xeb",
+    0x000005dc => "\xec",
+    0x000005dd => "\xed",
+    0x000005de => "\xee",
+    0x000005df => "\xef",
+    0x000005e0 => "\xf0",
+    0x000005e1 => "\xf1",
+    0x000005e2 => "\xf2",
+    0x000005e3 => "\xf3",
+    0x000005e4 => "\xf4",
+    0x000005e5 => "\xf5",
+    0x000005e6 => "\xf6",
+    0x000005e7 => "\xf7",
+    0x000005e8 => "\xf8",
+    0x000005e9 => "\xf9",
+    0x000005ea => "\xfa",
+    0x0000200e => "\xfd",
+    0x0000200f => "\xfe",
+    0x00002017 => "\xdf",
 );
 
 sub _recode
@@ -827,7 +791,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_10 - Conversion routines for ISO-8859-10
+Locale::RecodeData::ISO_8859_8 - Conversion routines for ISO-8859-8
 
 =head1 SYNOPSIS
 
@@ -836,7 +800,7 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-10.
+routines for ISO-8859-8.
 
 =head1 COMMENTS
 
@@ -844,11 +808,10 @@ The following comments have been extracted from the original charmap:
 
  version: 1.0
   source: ECMA registry
- alias ISO-IR-157
- alias ISO_8859-10:1992
- alias ISO_8859-10
- alias L6
- alias LATIN6
+ alias ISO-IR-138
+ alias ISO_8859-8:1988
+ alias ISO_8859-8
+ alias HEBREW
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -1021,101 +984,65 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  00000104 | LATIN CAPITAL LETTER A WITH OGONEK
-    A2 |  00000112 | LATIN CAPITAL LETTER E WITH MACRON
-    A3 |  00000122 | LATIN CAPITAL LETTER G WITH CEDILLA
-    A4 |  0000012A | LATIN CAPITAL LETTER I WITH MACRON
-    A5 |  00000128 | LATIN CAPITAL LETTER I WITH TILDE
-    A6 |  00000136 | LATIN CAPITAL LETTER K WITH CEDILLA
+    A2 |  000000A2 | CENT SIGN
+    A3 |  000000A3 | POUND SIGN
+    A4 |  000000A4 | CURRENCY SIGN
+    A5 |  000000A5 | YEN SIGN
+    A6 |  000000A6 | BROKEN BAR
     A7 |  000000A7 | SECTION SIGN
-    A8 |  0000013B | LATIN CAPITAL LETTER L WITH CEDILLA
-    A9 |  00000110 | LATIN CAPITAL LETTER D WITH STROKE
-    AA |  00000160 | LATIN CAPITAL LETTER S WITH CARON
-    AB |  00000166 | LATIN CAPITAL LETTER T WITH STROKE
-    AC |  0000017D | LATIN CAPITAL LETTER Z WITH CARON
+    A8 |  000000A8 | DIAERESIS
+    A9 |  000000A9 | COPYRIGHT SIGN
+    AA |  000000D7 | MULTIPLICATION SIGN
+    AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
+    AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
-    AE |  0000016A | LATIN CAPITAL LETTER U WITH MACRON
-    AF |  0000014A | LATIN CAPITAL LETTER ENG (Sami)
+    AE |  000000AE | REGISTERED SIGN
+    AF |  000000AF | MACRON
     B0 |  000000B0 | DEGREE SIGN
-    B1 |  00000105 | LATIN SMALL LETTER A WITH OGONEK
-    B2 |  00000113 | LATIN SMALL LETTER E WITH MACRON
-    B3 |  00000123 | LATIN SMALL LETTER G WITH CEDILLA
-    B4 |  0000012B | LATIN SMALL LETTER I WITH MACRON
-    B5 |  00000129 | LATIN SMALL LETTER I WITH TILDE
-    B6 |  00000137 | LATIN SMALL LETTER K WITH CEDILLA
+    B1 |  000000B1 | PLUS-MINUS SIGN
+    B2 |  000000B2 | SUPERSCRIPT TWO
+    B3 |  000000B3 | SUPERSCRIPT THREE
+    B4 |  000000B4 | ACUTE ACCENT
+    B5 |  000000B5 | MICRO SIGN
+    B6 |  000000B6 | PILCROW SIGN
     B7 |  000000B7 | MIDDLE DOT
-    B8 |  0000013C | LATIN SMALL LETTER L WITH CEDILLA
-    B9 |  00000111 | LATIN SMALL LETTER D WITH STROKE
-    BA |  00000161 | LATIN SMALL LETTER S WITH CARON
-    BB |  00000167 | LATIN SMALL LETTER T WITH STROKE
-    BC |  0000017E | LATIN SMALL LETTER Z WITH CARON
-    BD |  00002015 | HORIZONTAL BAR
-    BE |  0000016B | LATIN SMALL LETTER U WITH MACRON
-    BF |  0000014B | LATIN SMALL LETTER ENG (Sami)
-    C0 |  00000100 | LATIN CAPITAL LETTER A WITH MACRON
-    C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
-    C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
-    C3 |  000000C3 | LATIN CAPITAL LETTER A WITH TILDE
-    C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
-    C5 |  000000C5 | LATIN CAPITAL LETTER A WITH RING ABOVE
-    C6 |  000000C6 | LATIN CAPITAL LETTER AE
-    C7 |  0000012E | LATIN CAPITAL LETTER I WITH OGONEK
-    C8 |  0000010C | LATIN CAPITAL LETTER C WITH CARON
-    C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
-    CA |  00000118 | LATIN CAPITAL LETTER E WITH OGONEK
-    CB |  000000CB | LATIN CAPITAL LETTER E WITH DIAERESIS
-    CC |  00000116 | LATIN CAPITAL LETTER E WITH DOT ABOVE
-    CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
-    CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
-    CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
-    D0 |  000000D0 | LATIN CAPITAL LETTER ETH (Icelandic)
-    D1 |  00000145 | LATIN CAPITAL LETTER N WITH CEDILLA
-    D2 |  0000014C | LATIN CAPITAL LETTER O WITH MACRON
-    D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
-    D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
-    D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
-    D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
-    D7 |  00000168 | LATIN CAPITAL LETTER U WITH TILDE
-    D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
-    D9 |  00000172 | LATIN CAPITAL LETTER U WITH OGONEK
-    DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
-    DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
-    DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
-    DD |  000000DD | LATIN CAPITAL LETTER Y WITH ACUTE
-    DE |  000000DE | LATIN CAPITAL LETTER THORN (Icelandic)
-    DF |  000000DF | LATIN SMALL LETTER SHARP S (German)
-    E0 |  00000101 | LATIN SMALL LETTER A WITH MACRON
-    E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
-    E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
-    E3 |  000000E3 | LATIN SMALL LETTER A WITH TILDE
-    E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
-    E5 |  000000E5 | LATIN SMALL LETTER A WITH RING ABOVE
-    E6 |  000000E6 | LATIN SMALL LETTER AE
-    E7 |  0000012F | LATIN SMALL LETTER I WITH OGONEK
-    E8 |  0000010D | LATIN SMALL LETTER C WITH CARON
-    E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
-    EA |  00000119 | LATIN SMALL LETTER E WITH OGONEK
-    EB |  000000EB | LATIN SMALL LETTER E WITH DIAERESIS
-    EC |  00000117 | LATIN SMALL LETTER E WITH DOT ABOVE
-    ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
-    EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
-    EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
-    F0 |  000000F0 | LATIN SMALL LETTER ETH (Icelandic)
-    F1 |  00000146 | LATIN SMALL LETTER N WITH CEDILLA
-    F2 |  0000014D | LATIN SMALL LETTER O WITH MACRON
-    F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
-    F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
-    F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
-    F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
-    F7 |  00000169 | LATIN SMALL LETTER U WITH TILDE
-    F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
-    F9 |  00000173 | LATIN SMALL LETTER U WITH OGONEK
-    FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
-    FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
-    FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
-    FD |  000000FD | LATIN SMALL LETTER Y WITH ACUTE
-    FE |  000000FE | LATIN SMALL LETTER THORN (Icelandic)
-    FF |  00000138 | LATIN SMALL LETTER KRA (Greenlandic)
+    B8 |  000000B8 | CEDILLA
+    B9 |  000000B9 | SUPERSCRIPT ONE
+    BA |  000000F7 | DIVISION SIGN
+    BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
+    BC |  000000BC | VULGAR FRACTION ONE QUARTER
+    BD |  000000BD | VULGAR FRACTION ONE HALF
+    BE |  000000BE | VULGAR FRACTION THREE QUARTERS
+    DF |  00002017 | DOUBLE LOW LINE
+    E0 |  000005D0 | HEBREW LETTER ALEF
+    E1 |  000005D1 | HEBREW LETTER BET
+    E2 |  000005D2 | HEBREW LETTER GIMEL
+    E3 |  000005D3 | HEBREW LETTER DALET
+    E4 |  000005D4 | HEBREW LETTER HE
+    E5 |  000005D5 | HEBREW LETTER VAV
+    E6 |  000005D6 | HEBREW LETTER ZAYIN
+    E7 |  000005D7 | HEBREW LETTER HET
+    E8 |  000005D8 | HEBREW LETTER TET
+    E9 |  000005D9 | HEBREW LETTER YOD
+    EA |  000005DA | HEBREW LETTER FINAL KAF
+    EB |  000005DB | HEBREW LETTER KAF
+    EC |  000005DC | HEBREW LETTER LAMED
+    ED |  000005DD | HEBREW LETTER FINAL MEM
+    EE |  000005DE | HEBREW LETTER MEM
+    EF |  000005DF | HEBREW LETTER FINAL NUN
+    F0 |  000005E0 | HEBREW LETTER NUN
+    F1 |  000005E1 | HEBREW LETTER SAMEKH
+    F2 |  000005E2 | HEBREW LETTER AYIN
+    F3 |  000005E3 | HEBREW LETTER FINAL PE
+    F4 |  000005E4 | HEBREW LETTER PE
+    F5 |  000005E5 | HEBREW LETTER FINAL TSADI
+    F6 |  000005E6 | HEBREW LETTER TSADI
+    F7 |  000005E7 | HEBREW LETTER QOF
+    F8 |  000005E8 | HEBREW LETTER RESH
+    F9 |  000005E9 | HEBREW LETTER SHIN
+    FA |  000005EA | HEBREW LETTER TAV
+    FD |  0000200E | LEFT-TO-RIGHT MARK
+    FE |  0000200F | RIGHT-TO-LEFT MARK
 
 
 =head1 AUTHOR
